@@ -1,21 +1,7 @@
 /*
-    Copyright 2008 Sascha Peilicke <sasch.pe@gmx.de>
+    SPDX-FileCopyrightText: 2008 Sascha Peilicke <sasch.pe@gmx.de>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "gamescene.h"
@@ -138,17 +124,18 @@ void GameScene::showTerritory(bool show)
 
 void GameScene::updateStoneItems()
 {
-    QGraphicsPixmapItem *stoneItem;
     const int halfStoneSize = m_stonePixmapSize.width() / 2;
 
     const Stone lastStone = (m_game->moves().size() > 0) ? m_game->lastMove().stone() : Stone::Invalid;
 
-    foreach (stoneItem, m_stoneItems) {  // Clear all stone items
+    for (QGraphicsPixmapItem *stoneItem : std::as_const(m_stoneItems)) {  // Clear all stone items
         removeItem(stoneItem);
     }
     m_stoneItems.clear();
 
-    foreach (const Stone &stone, m_game->stones(m_game->blackPlayer())) {
+    QGraphicsPixmapItem *stoneItem;
+    const auto blackStones = m_game->stones(m_game->blackPlayer());
+    for (const Stone &stone : blackStones) {
         ThemeRenderer::Element element = (stone == lastStone) ? ThemeRenderer::Element::BlackStoneLast : ThemeRenderer::Element::BlackStone;
         stoneItem = addPixmap(ThemeRenderer::self()->renderElement(element, m_stonePixmapSize));
         stoneItem->setZValue(2);
@@ -157,7 +144,8 @@ void GameScene::updateStoneItems()
                              m_gridRect.y() + (m_boardSize - stone.y()) * m_cellSize - halfStoneSize + 1));
         m_stoneItems.append(stoneItem);
     }
-    foreach (const Stone &stone, m_game->stones(m_game->whitePlayer())) {
+    const auto whiteStones = m_game->stones(m_game->whitePlayer());
+    for (const Stone &stone : whiteStones) {
         ThemeRenderer::Element element = (stone == lastStone) ? ThemeRenderer::Element::WhiteStoneLast : ThemeRenderer::Element::WhiteStone;
         stoneItem = addPixmap(ThemeRenderer::self()->renderElement(element, m_stonePixmapSize));
         stoneItem->setZValue(2);
@@ -169,7 +157,8 @@ void GameScene::updateStoneItems()
 
     if (m_showMoveNumbers) {
         int i = 0;
-        foreach (const Move &move, m_game->moves()) {
+        const auto moves = m_game->moves();
+        for (const Move &move : moves) {
             int xOff = move.stone().x() >= 'I' ? move.stone().x() - 'A' - 1 : move.stone().x() - 'A';
             QPointF pos = QPointF(m_gridRect.x() + xOff * m_cellSize,
                                   m_gridRect.y() + (m_boardSize - move.stone().y()) * m_cellSize);
@@ -197,17 +186,18 @@ void GameScene::updateStoneItems()
 
 void GameScene::updateHintItems()
 {
-    QGraphicsPixmapItem *item;
-
-    foreach (item, m_hintItems) {   // Old hint is invalid, remove it first
+    for (QGraphicsPixmapItem *item : std::as_const(m_hintItems)) {   // Old hint is invalid, remove it first
         removeItem(item);
     }
     m_hintItems.clear();
 
+    QGraphicsPixmapItem *item;
+
     if (m_showHint) {
         const int halfStoneSize = m_stonePixmapSize.width() / 2;
 
-        foreach (const Stone &move, m_game->bestMoves(m_game->currentPlayer())) {
+        const auto moves = m_game->bestMoves(m_game->currentPlayer());
+        for (const Stone &move : moves) {
             QPixmap stonePixmap;
             if (m_game->currentPlayer().isWhite()) {
                 stonePixmap = ThemeRenderer::self()->renderElement(ThemeRenderer::Element::WhiteStoneTransparent, m_stonePixmapSize);
@@ -239,20 +229,21 @@ void GameScene::updateHintItems()
 
 void GameScene::updateTerritoryItems()
 {
-    QGraphicsPixmapItem *item;
-
-    foreach (item, m_territoryItems) {  // Old territory is invalid, remove it first
+    for(QGraphicsPixmapItem *item : std::as_const(m_territoryItems)) {  // Old territory is invalid, remove it first
         removeItem(item);
     }
     m_territoryItems.clear();
 
+    QGraphicsPixmapItem *item;
+
     if (m_showTerritory) {
         QPixmap stonePixmap;
         const int halfCellSize = m_cellSize / 2;
         //qCDebug(KIGO_LOG) << "Fetching territory from engine ...";
 
         stonePixmap = ThemeRenderer::self()->renderElement(ThemeRenderer::Element::WhiteTerritory, QSize(m_cellSize, m_cellSize));
-        foreach (const Stone &stone, m_game->finalStates(Game::FinalState::FinalWhiteTerritory)) {
+        const auto whiteStones = m_game->finalStates(Game::FinalState::FinalWhiteTerritory);
+        for (const Stone &stone : whiteStones) {
             item = addPixmap(stonePixmap);
             item->setZValue(8);
             const int xOff = stone.x() >= 'I' ? stone.x() - 'A' - 1 : stone.x() - 'A';
@@ -262,7 +253,8 @@ void GameScene::updateTerritoryItems()
         }
 
         stonePixmap = ThemeRenderer::self()->renderElement(ThemeRenderer::Element::BlackTerritory, QSize(m_cellSize, m_cellSize));
-        foreach (const Stone &stone, m_game->finalStates(Game::FinalState::FinalBlackTerritory)) {
+        const auto blackStones = m_game->finalStates(Game::FinalState::FinalBlackTerritory);
+        for (const Stone &stone : blackStones) {
             item = addPixmap(stonePixmap);
             item->setZValue(8);
             const int xOff = stone.x() >= 'I' ? stone.x() - 'A' - 1 : stone.x() - 'A';
@@ -311,11 +303,11 @@ void GameScene::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
             } else if (m_game->currentPlayer().isBlack()) {
                 map = ThemeRenderer::self()->renderElement(ThemeRenderer::Element::BlackStoneTransparent, m_stonePixmapSize);
             }
-            emit cursorPixmapChanged(map);
+            Q_EMIT cursorPixmapChanged(map);
         }
     } else {
         m_placementMarkerItem->setVisible(false);
-        emit cursorPixmapChanged(map);
+        Q_EMIT cursorPixmapChanged(map);
     }
 }
 
